@@ -21,6 +21,7 @@ from requests.exceptions import InvalidURL, RequestException, Timeout
 from requests.models import Response
 
 from .default import PKG2PROJECT
+from .progress_bars import rich_progress_bar
 
 
 def parse_url(url: str) -> Tuple[str, str]:
@@ -172,13 +173,12 @@ def download_from_file(url: str,
     size = int(response.headers.get('content-length'))
     with open(dest_path, 'wb') as fw:
         content_iter = response.iter_content(chunk_size=1024)
-        with click.progressbar(content_iter, length=size / 1024) as chunks:
-            for chunk in chunks:
-                if chunk:
-                    fw.write(chunk)
-                    fw.flush()
-                    if hash_prefix is not None:
-                        sha256.update(chunk)
+        for chunk in rich_progress_bar(content_iter, size=size):
+            if chunk:
+                fw.write(chunk)
+                fw.flush()
+                if hash_prefix is not None:
+                    sha256.update(chunk)
 
     if hash_prefix is not None:
         digest = sha256.hexdigest()
@@ -218,7 +218,7 @@ def get_package_version(repo_root: str) -> Tuple[str, str]:
     for file_name in os.listdir(repo_root):
         version_path = osp.join(repo_root, file_name, 'version.py')
         if osp.exists(version_path):
-            with open(version_path, 'r', encoding='utf-8') as f:
+            with open(version_path, encoding='utf-8') as f:
                 exec(compile(f.read(), version_path, 'exec'))
             return file_name, locals()['__version__']
 
@@ -236,7 +236,7 @@ def get_installed_version(package: str) -> str:
 
 
 def get_package_info_from_pypi(package: str, timeout: int = 15) -> dict:
-    """Get packege information from pypi.
+    """Get package information from pypi.
 
     Args:
         package (str): Package to get information.
